import { Box, Container, Stack } from "@styled-system/jsx";
import { getAbout, getHome } from "@/api";

import Gallery from "./gallery";
import Image from "next/image";
import { Media } from "@/payload-types";
import { Metadata } from "next";
import RichText from "@/components/rich-text";
import { css } from "@styled-system/css";
import { styled } from "@styled-system/jsx";

export default async function Home() {
  const home = await getHome();
  const about = await getAbout();

  return (
    <Stack gap={10} align="center">
      <Box w="100%" h="80vh" position="relative">
        <Image
          src={(home.splashImage as Media)!.url!}
          alt={about.name}
          className={css({ objectFit: "cover" })}
          fill
        />
        <styled.div
          position="absolute"
          color="white"
          top="60%"
          width="100%"
          textAlign="center"
          fontSize={36}
        >
          {home.tagline}
        </styled.div>
      </Box>
      <Container>
        <RichText content={home.aboutText} />
      </Container>
      <Box maxW={600} w="100%" h="60vh">
        <Gallery />
      </Box>
    </Stack>
  );
}
