import { ChevronLeftIcon, ChevronRightIcon } from "lucide-react";
import {
  Control,
  Indicator,
  IndicatorGroup,
  Item,
  ItemGroup,
  NextTrigger,
  PrevTrigger,
  Root,
  RootProps,
  Viewport,
} from "./styled/carousel";

import { IconButton } from "@/components/ui/icon-button";
import Image from "next/image";
import { Media } from "@/payload-types";
import { css } from "@styled-system/css";
import { styled } from "@styled-system/jsx";

export type CarouselProps = RootProps & {
  images: Media[];
};

export default function Carousel({ images, ...props }: CarouselProps) {
  return (
    <Root h="100%" {...props}>
      <Viewport h="100%">
        <ItemGroup style={{ height: "100%" }}>
          {images.map((image, index) => (
            <Item key={index} index={index}>
              <styled.div h="100%" width="100%" position="relative">
                <Image
                  src={image.url!}
                  alt={image.alt ?? ""}
                  className={css({ objectFit: "contain" })}
                  fill
                />
              </styled.div>
            </Item>
          ))}
        </ItemGroup>
        <Control>
          <PrevTrigger asChild>
            <IconButton size="sm" variant="link" aria-label="Previous Slide">
              <ChevronLeftIcon />
            </IconButton>
          </PrevTrigger>
          <IndicatorGroup>
            {images.map((_, index) => (
              <Indicator key={index} index={index} aria-label={`Goto slide ${index + 1}`} />
            ))}
          </IndicatorGroup>
          <NextTrigger asChild>
            <IconButton size="sm" variant="link" aria-label="Next Slide">
              <ChevronRightIcon />
            </IconButton>
          </NextTrigger>
        </Control>
      </Viewport>
    </Root>
  );
}
