import type { GlobalConfig } from "payload";

export const Contact: GlobalConfig = {
  slug: "contact",
  access: {
    read: () => true,
  },
  fields: [
    {
      name: "email",
      type: "email",
    },
    {
      name: "phone",
      type: "text",
    },
    {
      name: "address",
      type: "group",
      fields: [
        {
          type: "row",
          fields: [
            {
              name: "street",
              type: "text",
              required: true,
            },
            {
              name: "number",
              type: "number",
              required: true,
            },
          ],
        },
        {
          type: "row",
          fields: [
            {
              name: "zip",
              type: "number",
              required: true,
            },
            {
              name: "area",
              type: "text",
              required: true,
            },
          ],
        },
        {
          name: "embeddedMaps",
          type: "code",
        },
        {
          name: "embeddedMapsNotice",
          type: "ui",
          admin: {
            components: {
              Field: () => (
                <p>
                  Use a generator like <a href="https://www.maps.ie/create-google-map/">maps.ie</a>{" "}
                  to create a Google Maps embed.
                </p>
              ),
            },
          },
        },
      ],
    },
    {
      name: "socialLinks",
      type: "array",
      fields: [
        {
          name: "link",
          type: "text",
          required: true,
        },
        {
          name: "type",
          type: "select",
          options: [
            {
              label: "Facebook",
              value: "facebook",
            },
            {
              label: "Instagram",
              value: "instagram",
            },
            {
              label: "LinkedIn",
              value: "linkedin",
            },
            {
              label: "LocalSearch",
              value: "localsearch",
            },
            {
              label: "X (Twitter)",
              value: "twitter",
            },
          ],
          required: true,
        },
      ],
    },
  ],
};
